==> kpogre_1.6.2.orig.tar.gz: kpogre-1.6.2/kpogre/Wizards/kpg6stepswizard.h <==
//
// C++ Interface: kpg6stepswizard
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPG6STEPSWIZARD_H
#define KPG6STEPSWIZARD_H

#include "kpg6stepswizardbase.h"

class KPGSyntaxHighlighter;
class KPGConnection;

/**
  * Wizard with 6 steps
  *
  * @author Lumir Vanek
  */
class KPG6StepsWizard : public KPG6StepsWizardBase
{
Q_OBJECT
public:
    KPG6StepsWizard(QWidget *parent = 0, const char *name = 0);
    ~KPG6StepsWizard();

	// Set connection to database
	void setConnection(KPGConnection *);

	// Return connection
    KPGConnection * connection() const { return m_pConnection; }
		
	QWidget * pageWidget1() { return m_pPageWidget1; }
	QWidget * pageWidget2() { return m_pPageWidget2; }
	QWidget * pageWidget3() { return m_pPageWidget3; }
	QWidget * pageWidget4() { return m_pPageWidget4; }

protected:
    // Run SQL query - as final Wizard operation
    void runQuery(bool = true);  
        			
protected:
	QWidget *m_pPageWidget1;
	QWidget *m_pPageWidget2;
	QWidget *m_pPageWidget3;
	QWidget *m_pPageWidget4;
		
private:  
    KPGConnection *m_pConnection;
		
  	/** Syntax highlighter for m_pTextEditSQL */
  	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
				
protected slots:
	// Enable/disable next button for 1st page
	void slotEnableNextButton1(bool);

	// Enable/disable next button for 2nd page
	void slotEnableNextButton2(bool);
		
	// Enable/disable next button for 3rd page
	void slotEnableNextButton3(bool);
		
	// Enable/disable next button for 4th page
	void slotEnableNextButton4(bool);
};

#endif

==> kpogre-1.6.6.tar.gz: kpogre-1.6.6/kpogre/Wizards/kpg6stepswizard.h <==
//
// C++ Interface: kpg6stepswizard
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPG6STEPSWIZARD_H
#define KPG6STEPSWIZARD_H

#include "kpg6stepswizardbase.h"

class KPGSyntaxHighlighter;
class KPGConnection;

/**
  * Wizard with 6 steps
  *
  * @author Lumir Vanek
  */
class KPG6StepsWizard : public KPG6StepsWizardBase
{
	Q_OBJECT
public:
    KPG6StepsWizard(QWidget *parent = 0, const char *name = 0);
    ~KPG6StepsWizard();

	// Set connection to database
	void setConnection(KPGConnection *);

	// Return connection
    KPGConnection * connection() const { return m_pConnection; }
		
	QWidget * pageWidget1() { return m_pPageWidget1; }
	QWidget * pageWidget2() { return m_pPageWidget2; }
	QWidget * pageWidget3() { return m_pPageWidget3; }
	QWidget * pageWidget4() { return m_pPageWidget4; }

protected:
	
    // Run SQL query - as final Wizard operation
    void runQuery(bool = true);  
        			
protected:
	
	QWidget *m_pPageWidget1;
	QWidget *m_pPageWidget2;
	QWidget *m_pPageWidget3;
	QWidget *m_pPageWidget4;
		
private:  
	
    // Connection to database
	KPGConnection *m_pConnection;
		
  	// Syntax highlighter for m_pTextEditSQL
	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
	
	// Noticications list
	QStringList m_listOfNotifications;
				
protected slots:
	
	// Enable/disable next button for 1st page
	void slotEnableNextButton1(bool);

	// Enable/disable next button for 2nd page
	void slotEnableNextButton2(bool);
		
	// Enable/disable next button for 3rd page
	void slotEnableNextButton3(bool);
		
	// Enable/disable next button for 4th page
	void slotEnableNextButton4(bool);
			
	// Process notice from connection
	void slotProcessNotice(QString);
};

#endif
